from cgitb import html
from itertools import tee
import requests
from bs4 import BeautifulSoup
from ratelimit import limits, sleep_and_retry

import shared
# from shared.suffix_parser import get_publication_year_from_suffix

from doi import doi_parser


@sleep_and_retry
@limits(calls=50,
        period=1)  # Allows 50 requets within 1 second; sleep till the request period has ellapsed and then retry
def find_mr_and_metadata(author, title, suffix):
    first_page, last_page = shared.get_page_range_from_suffix(suffix)
    year = shared.get_publication_year_from_suffix(suffix)

    range_pages = ""
    if first_page != "" and last_page != "":
        range_pages = f"{first_page}-{last_page}"

    doi = doi_parser.parser({"query.author":author,"query.title" : title, "query.bibliographic" : suffix})["doi"]

    payload = {
        "pg4": "AUCN",
        "s4": f"{author}",
        "co4": "AND",
        "pg5": "TI",
        "s5": f"{title}",
        "co5": "AND",
        "pg6": "ALLF",
        "s6": f"{range_pages}",
        "co6": "OR",
        "pg7": "DOI",
        "s7": f"{doi}",
        "co7": "AND",
        "yrop": "eq",
        "arg3": "",
        "dr": "pubyear",
        "yearRangeFirst": f"{year-1}",
        "yearRangeSecond": f"{year+1}",
        "pg8": "ET",
        "s8": "All",
        "review_format": "html",
        "Submit": "Search"
    }


    html_text = requests.get("https://mathscinet.ams.org/mathscinet/search/publications.html", params=payload).text
    soup = BeautifulSoup(html_text, features="lxml")

    mr_books = soup.select_one("#content > form > div.row.has-side-left > div.row-body > div > div > div.headline.first > div.headlineText > a.mrnum > strong")
    mr_book = soup.select_one("#content > div.doc > div.headline > strong:nth-child(2)")

    if mr_books is not None:
        mr = mr_books.text
        mr_link = f"https://mathscinet.ams.org/mathscinet-getitem?mr={mr[2:]}"
        return mr, mr_link

    if mr_book is not None:
        mr = mr_book.text
        mr_link = f"https://mathscinet.ams.org/mathscinet-getitem?mr={mr[2:]}"
        return mr, mr_link
    return "", ""


def check_access_to_advanced_search():
    html_text = requests.get("https://mathscinet.ams.org/mathscinet/search/publications.html?pg4=AUCN&s4=Fučík+S*&co4=AND&pg5=TI&s5=Solvability+of+nonlinear+equations+and+boundary+value+problems&co5=AND&pg6=PC&s6=&co6=AND&pg7=ALLF&s7=&co7=AND&dr=pubyear&yrop=eq&arg3=&yearRangeFirst=&yearRangeSecond=&pg8=ET&s8=All&review_format=html&Submit=Search").text
    soup = BeautifulSoup(html_text, features="lxml")

    access = soup.find("title").text
    if access == "MathSciNet Access Error":
        return False
    return True

if __name__ == '__main__':
    find_mr_and_metadata("author", "title", "suffix")