from venv import create
from doi.doi_parser import parser as doi_parser
from zbl.zbl_parser import parser as zbl_parser
from mr.mr_parser import parser as mr_parser

def create_query(author,title,bibliographic):
    query = {}
    query["query.author"] = author
    query["query.bibliographic"] = bibliographic
    query["query.title"] = title
    return query


def test_doi_parser():
    expected_result = "10.1007/bf01352146"
    query = create_query("Dinghas A.","Superadditive Funktionale, Identitäten und Ungleichungen der elementaren Analysis","Math. Ann., vol. 178, 1968, 315-334.")
    actual_result = doi_parser(query)["doi"]
    assert expected_result == actual_result

def test_zbl_parser_one_result_on_page():
    expected_result = "Zbl 1150.11339"
    query = create_query("Grekos, G","On various definitions of density","(survey), Tatra Mt. Math. Publ. 31 (2005) 17–27")
    actual_result = zbl_parser(query)["zbl"]
    assert expected_result == actual_result

def test_zbl_parser_more_results_on_page():
    expected_result = "Zbl 0880.11001"
    query = create_query("Tenenbaum, G.","Introduction to analytic and probabilistic number theory","Cambridge Univ. Press, Cambridge, 1995")
    actual_result = zbl_parser(query)["zbl"]
    assert expected_result == actual_result

def test_mr_parser():
    expected_result = "MR2397737"
    query = create_query("Taylor, M. D.","Multivariate measures of concordance.","Ann. Inst. Statist. Math. 59 (2007), no. 4, 789-806")
    actual_result = mr_parser(query)["mr"]
    assert expected_result == actual_result



